import fire
import boto3
import sys
from botocore.client import ClientError

S3 = boto3.resource('s3')


class Cull(object):
    def ec2(self, cloud, service):
        """
        Parse EC2 instances
        
        :param cloud: String 
        :param service: String
        :return: None
        """
        ec2 = boto3.resource('ec2')

        filters = [{'Name': 'tag:Name', 'Values': ["{0}_{1}_*".format(cloud, service)]}]

        instance_names = [tag['Value'] for instance in ec2.instances.filter(Filters=filters) for tag in instance.tags if
                          tag['Key'] == 'Name']

        instance_ips = [instance.private_ip_address for instance in ec2.instances.filter(Filters=filters)]

        instance_ids = [instance.instance_id for instance in ec2.instances.filter(Filters=filters)]

        for index, name in enumerate(instance_names):
            print "Name:" + name + " | ID:" + instance_ids[index] + " | ssh://ubuntu@" + instance_ips[index]

    def s3list(self, cloud):
        """
        Parse S3 buckets
        
        :param cloud: String
        :return: None
        """

        cloud_buckets = [bucket.name for bucket in S3.buckets.all() if cloud in bucket.name]
        print "\n".join(cloud_buckets)

    def s3delete(self):
        """
        Delete S3 bucket(s)
        
        :return: None 
        """
        try:
            buckets_to_delete = raw_input('Bucket names (use spaces to pass multiple names)?:').split()
            print 'Are you sure? The following bucket(s) will be deleted...'
            print '\n'.join(buckets_to_delete)
            answer = raw_input('Only YES accepted:')

            if answer == 'YES':
                for bucket in buckets_to_delete:
                    try:
                        # check to see if bucket exists
                        S3.meta.client.head_bucket(Bucket=bucket)
                        bucket = S3.Bucket(bucket)
                        print 'Deleting...'
                        for key in bucket.objects.all():
                            key.delete()
                        bucket.delete()
                        print "{0} bucket deleted.".format(bucket.name)
                    except ClientError:
                        print "{0} bucket does exists or you do not have permission to {0}.".format(bucket)
            else:
                print 'Delete aborted.'
                return None
        except KeyboardInterrupt:
            print '\nCaught Ctrl-C, exiting.\n'
            sys.exit()


def main():
    fire.Fire(Cull)


if __name__ == '__main__':
    main()
